"""
CS 1 23fa 
Lab 05 Provided Backend Code
Original Author: Leo Jenkins
"""
import csv

def get_angels_data():
    """
    Returns a (list, list) tuple of game numbers and wins,
    respectively, for the Angels in 2022. Data comes from
    angels_wins_2022.csv. Both lists contain int values only.

    Returns:
        - (list, list) tuple representing number of games and wins
    """
    ANGELS_DATASET = 'angels_wins_2022.csv'
    with open(ANGELS_DATASET, 'r') as csv_file:
        csv_reader = csv.DictReader(csv_file)

        xs = []
        ys = []

        wins = 0
        for row in csv_reader:
            # Convert string values to ints for plotting
            xs.append(int(row['Gm#']))
            if row['W/L'] == 'W':
                wins += 1
            ys.append(wins)

    return (xs, ys)
       

def get_bitcoin_data():
    """
    Returns a (list, list) tuple of dates and prices for
    Bitcoins collected from bitcoin_historical_data.csv.
    Dates are represented as strings, and prices are represented as floats.

    Returns:
        - (list, list) tuple representing dates and prices for Bitcoin data
    """
    BITCOIN_DATASET = 'bitcoin_historical_data.csv'
    with open(BITCOIN_DATASET, 'r') as csv_file:
        csv_reader = csv.DictReader(csv_file)

        xs = []
        ys = []

        for row in csv_reader:
            xs.append(row['Date'])
            # Standardize price value (which may have ,) to float
            # (it's good to break apart these steps for debugging!)
            price = row['Price'] # e.g. '20,000.99'
            price = price.replace(',', '')  # e.g. '20000.99'
            price = float(price) # e.g. 20000.99
            ys.append(price)

    # We're done processing the file, so we end the with block

    # Reverse the lists (from list reading!) since dates (xs) are in descending
    # order in our dataset, and we need to make sure the prices (ys) stay
    # corresponding to the correct dates (remember that xs[i] and ys[i] must
    # match as a single (xi, yi) data point)
    xs = xs[::-1]
    ys = ys[::-1]
    return (xs, ys) 
